@@ -12,8 +12,7 @@
 
    Copyright 2021, HSPyLib team
 """
-from modules.cli.icons.font_awesome.awesome import Awesome
-
+from hspylib.modules.cli.icons.font_awesome.awesome import Awesome
 
 class DashboardIcons(Awesome):
     """
