@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.cli.tui
+   @package: main.modules.cli.tui
       @file: tui.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -15,7 +15,6 @@
 
 from abc import ABC, abstractmethod
 
-
 class Menu(ABC):
     """TODO"""
 
