@@ -16,13 +16,12 @@
 from typing import Any, List, Optional, Tuple, Union
 
 import requests
+from hspylib.core.enums.http_code import HttpCode
+from hspylib.core.enums.http_method import HttpMethod
+from hspylib.core.tools.commons import sysout
+from hspylib.modules.fetch.http_response import HttpResponse
 from requests import exceptions as ex
 
-from core.enums.http_code import HttpCode
-from core.enums.http_method import HttpMethod
-from core.tools.commons import sysout
-from modules.fetch.http_response import HttpResponse
-
 
 def fetch(
     url: str,
