@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.qt.promotions
+   @package: main.modules.qt.promotions
       @file: hcombobox.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -15,7 +15,6 @@
 
 from PyQt5.QtWidgets import QComboBox
 
-
 class HComboBox(QComboBox):
 
     def set_item(self, item: str) -> None:
