@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.qt.promotions
+   @package: main.modules.qt.promotions
       @file: htableview.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -17,8 +17,8 @@ from typing import Optional
 
 import pyperclip as clipboard
 from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QPainter, QPaintEvent, QCursor
-from PyQt5.QtWidgets import QTableView, QWidget, QMenu, QHeaderView, QAbstractScrollArea
+from PyQt5.QtGui import QCursor, QPainter, QPaintEvent
+from PyQt5.QtWidgets import QAbstractScrollArea, QHeaderView, QMenu, QTableView, QWidget
 
 
 class HTableView(QTableView):
