@@ -19,9 +19,8 @@ from contextlib import redirect_stderr, redirect_stdout
 from time import sleep
 
 from PyQt5.QtCore import pyqtSignal, QThread
-
-from core.tools.commons import is_debugging, syserr
-from core.tools.preconditions import check_argument
+from hspylib.core.tools.commons import is_debugging, syserr
+from hspylib.core.tools.preconditions import check_argument
 
 
 class StreamCapturer(QThread):
